@@ -1,9 +1,9 @@
 
-#' Find Nearest \acronym{GSOD} Stations to a Specified Latitude and Longitude
+#' Find nearest \acronym{GSOD} stations to a specified latitude and longitude
 #'
 #' Given latitude and longitude values entered as decimal degrees (DD), this
-#' function returns a list (atomic vector) of \acronym{STNID} values, which can
-#' be used in \code{\link{get_GSOD}} to query for specific stations as an
+#' function returns a list (atomic vector) of \acronym{STATION} values, which
+#' can be used in \code{\link{get_GSOD}} to query for specific stations as an
 #' argument in the \code{station} parameter of that function.
 #'
 #' @param LAT Latitude expressed as decimal degrees (DD) (WGS84)
@@ -27,11 +27,10 @@
 #' n
 #'}
 #' @return \code{\link[base]{vector}} object of station identification numbers
-#' @author Adam H Sparks, \email{adamhsparks@@gmail.com}
+#' @author Adam H. Sparks, \email{adamhsparks@@gmail.com}
 #' @export nearest_stations
 
 nearest_stations <- function(LAT, LON, distance) {
-
   # CRAN NOTE avoidance
   isd_history <- NULL
   # load current local copy of isd_history
@@ -57,7 +56,8 @@ nearest_stations <- function(LAT, LON, distance) {
     )))
   }
 
-  nearby <- haversine_distance(isd_history["LAT"], isd_history["LON"], LAT, LON)
+  nearby <-
+    haversine_distance(isd_history$LAT, isd_history$LON, LAT, LON)
 
   nearby <- which(nearby < distance)
   return(isd_history[as.numeric(nearby), ]$STNID)
